fnss.topologies.datacenter.DatacenterTopology.neighbors_iter — FNSS 0.3.2 documentation

### Navigation

- index
- modules |
- modules |
- FNSS 0.3.2 documentation »

# fnss.topologies.datacenter.DatacenterTopology.neighbors_iter

`DatacenterTopology.` `neighbors_iter`(n)

  Return an iterator over all neighbors of node n.

  Notes

  It is faster to use the idiom “in G[0]”, e.g.

      >>> G = nx.path_graph(4)
      >>> [n for n in G[0]]
      [1]

  Examples

      >>> G = nx.Graph()   # or DiGraph, MultiGraph, MultiDiGraph, etc
      >>> G.add_path([0,1,2,3])
      >>> [n for n in G.neighbors_iter(0)]
      [1]

### Navigation

- index
- modules |
- modules |
- FNSS 0.3.2 documentation »